@@ -105,6 +105,20 @@ eos
       end
     end
 
+    context 'with step 4 with ovn' do
+      before do
+        params.merge!({
+          :step           => 4,
+          :bootstrap_node => 'node.example.com',
+          :neutron_driver => ['ovn']
+        })
+      end
+
+      it 'should should set provider drivers' do
+        is_expected.to contain_class('octavia::api').with(:provider_drivers => { 'amphora' => 'Octavia Amphora Driver', 'ovn' => 'Octavia OVN driver' })
+      end
+    end
+
     context 'with step 4 on non-bootstrap node' do
       before do
         params.merge!({ :step => 4 })
@@ -139,20 +153,10 @@ eos
               'service_key'         => '/foo.key',
             },
           },
-          :tls_proxy_bind_ip    => '172.16.10.25',
-          :tls_proxy_fqdn       => 'octavia-host.example.com',
-          :tls_proxy_port       => 9876
         })
       end
       it {
         is_expected.to contain_class('octavia::api')
-        is_expected.to contain_apache__vhost('octavia-api-proxy').with(
-          :ssl_cert     => '/foo.pem',
-          :ssl_key      => '/foo.key',
-          :ip           => '172.16.10.25',
-          :port         => 9876,
-          :servername   => 'octavia-host.example.com',
-        )
       }
     end
   end
